package org.apache.commons.lang3.time;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.text.DateFormatSymbols;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.Set;
import java.util.TimeZone;
import java.util.TreeSet;
import org.apache.commons.lang3.LocaleUtils;
import org.apache.commons.lang3.time.FastDateParser;
import org.apache.commons.lang3.time.FastTimeZone;

class TimeZoneStrategy extends FastDateParser.PatternStrategy {
  private static final String RFC_822_TIME_ZONE = "[+-]\\d{4}";
  
  private static final String GMT_OPTION = "GMT[+-]\\d{1,2}:\\d{2}";
  
  private final Locale locale;
  
  private final Map<String, TzInfo> tzNames = new HashMap<>();
  
  private static final int ID = 0;
  
  TimeZoneStrategy(Locale locale) {
    this.locale = LocaleUtils.toLocale(locale);
    StringBuilder sb = new StringBuilder();
    sb.append("((?iu)[+-]\\d{4}|GMT[+-]\\d{1,2}:\\d{2}");
    Set<String> sorted = new TreeSet<>(FastDateParser.access$800());
    String[][] zones = DateFormatSymbols.getInstance(locale).getZoneStrings();
    for (String[] zoneNames : zones) {
      String tzId = zoneNames[0];
      if (!tzId.equalsIgnoreCase("GMT")) {
        TimeZone tz = TimeZone.getTimeZone(tzId);
        TzInfo standard = new TzInfo(tz, false);
        TzInfo tzInfo = standard;
        for (int i = 1; i < zoneNames.length; i++) {
          switch (i) {
            case 3:
              tzInfo = new TzInfo(tz, true);
              break;
            case 5:
              tzInfo = standard;
              break;
          } 
          if (zoneNames[i] != null) {
            String key = zoneNames[i].toLowerCase(locale);
            if (sorted.add(key))
              this.tzNames.put(key, tzInfo); 
          } 
        } 
      } 
    } 
    for (String zoneName : sorted)
      FastDateParser.access$900(sb.append('|'), zoneName); 
    sb.append(")");
    createPattern(sb);
  }
  
  void setCalendar(FastDateParser parser, Calendar calendar, String timeZone) {
    TimeZone tz = FastTimeZone.getGmtTimeZone(timeZone);
    if (tz != null) {
      calendar.setTimeZone(tz);
    } else {
      String lowerCase = timeZone.toLowerCase(this.locale);
      TzInfo tzInfo = this.tzNames.get(lowerCase);
      if (tzInfo == null)
        tzInfo = this.tzNames.get(lowerCase + '.'); 
      calendar.set(16, tzInfo.dstOffset);
      calendar.set(15, tzInfo.zone.getRawOffset());
    } 
  }
  
  public String toString() {
    return "TimeZoneStrategy [locale=" + this.locale + ", tzNames=" + this.tzNames + ", pattern=" + this.pattern + "]";
  }
}
